@@ -5,21 +5,6 @@ use std::fmt::Debug;
 
 pub struct Add;
 
-const DEFINITION: &'static str ="
-name = 'Add'
-
-[[input]]
-name = 'i1'
-type = 'u32'
-
-[[input]]
-name = 'i2'
-type = 'u32'
-
-[[output]]
-name = 'o1'
-type = 'u32'";
-
 impl Implementation for Add {
     fn number_of_inputs(&self) -> usize {
         2
@@ -32,10 +17,6 @@ impl Implementation for Add {
         Some(o1.to_string())
     }
 
-    fn define(&self) -> &'static str {
-        DEFINITION
-    }
-
     fn name(&self) -> &'static str {
         "Add"
     }
